import 'package:flutter/widgets.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:suga_core/src/helpers/unit.dart';
import 'package:synchronized/synchronized.dart';

abstract class BaseViewModel {
  static final _callLock = Lock();

  void initState() {}

  void disposeState() {}

  @protected
  Future<Unit> call(
    dynamic Function() handler, {
    bool showLoading = true,
    dynamic Function()? onSuccess,
    dynamic Function(dynamic error)? onFailure,
  }) async {
    onFailure ??= (error) => Fluttertoast.showToast(msg: error.toString());
    return _callLock.synchronized<Unit>(() async {
      var success = true;
      try {
        if (showLoading) {
          await EasyLoading.show(status: "Please wait");
        }
        final result = handler();
        if (result is Future) {
          await result;
        }
      } catch (error) {
        success = false;
        final result = onFailure?.call(error);
        if (result is Future) {
          await result;
        }
      } finally {
        if (showLoading) {
          await EasyLoading.dismiss();
        }
        if (success) {
          final result = onSuccess?.call();
          if (result is Future) {
            await result;
          }
        }
      }
      return unit;
    });
  }
}
